<?php

namespace Drupal\commerce_tpay\PluginForm\TpayRedirect;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm as BasePaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\commerce_order\Entity\Order;

/**
 * Provides the Off-site payment form.
 */
class TpayPaymentForm extends BasePaymentOffsiteForm {
  
  const TPAY_API_URL = 'https://secure.tpay.com';
  
  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    
    $redirect_method = 'post';
    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();
    $order = $form_state->getFormObject()->getOrder();
    
    $sid = $payment_gateway_plugin->getConfiguration()['sid'];
    $confirmation_code = $payment_gateway_plugin->getConfiguration()['confirmation_code'];
    
    $billing_profile = $order->getBillingProfile();
    $address = $order->getBillingProfile()->address->first();
    
    $price = $payment->getAmount()->getNumber();
    $currency = $payment->getAmount()->getCurrencyCode();
    
    $crc = $order->id() . '/' . $currency;
    
    $parameters = [
      'id' => $sid,
      'kwota' => $price,
      'opis' => t('Zamówienie nr') . ' ' . $order->id(),
      'crc' => $crc,
      'md5sum' => md5($sid . $price . $crc . $confirmation_code),
      'nazwisko' => $address->getGivenName() . ' ' . $address->getFamilyName(),
      'adres' => $address->getAddressLine1(),
      'city' => $address->getLocality(),
      'kraj' => $address->getCountryCode(),
      'email' => $order->getEmail(),
      'wyn_url' => $payment_gateway_plugin->getNotifyUrl(),
      'pow_url' => $payment_gateway_plugin->getReturnUrl($order),
      'pow_url_blad' => $payment_gateway_plugin->getCancelUrl($order),
    ];
    
    $redirect_url = self::TPAY_API_URL;
    
    return $this->buildRedirectForm($form, $form_state, $redirect_url, $parameters, $redirect_method);
  }
}